import { select, range } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const svg = select(container)
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'skyblue');

  // Create a group for the birds
  const birdsGroup = svg.append('g');

  // Create an array of bird objects with initial positions
  const birds = range(5).map(() => ({
    x: Math.random() * width,
    y: Math.random() * height * 0.6,
    direction: Math.random() > 0.5 ? 1 : -1,
  }));

  // Create and append bird shapes to the birds group
  birdsGroup
    .selectAll('path')
    .data(birds)
    .enter()
    .append('path')
    .attr('d', 'M0 0 L10 5 L0 10 L3 5 Z')
    .attr('fill', 'black')
    .attr('transform', (d) => `translate(${d.x},${d.y})`);

  // Function to update bird positions
  const updateBirds = () => {
    birds.forEach((bird) => {
      bird.x += 2 * bird.direction; // Update bird's x position
      if (bird.x > width + 20) {
        bird.x = -20; // Reset x position if bird goes off the screen to the right
      } else if (bird.x < -20) {
        bird.x = width + 20; // Reset x position if bird goes off the screen to the left
      }
    });

    // Update bird positions
    birdsGroup
      .selectAll('path')
      .data(birds)
      .attr('transform', (d) => `translate(${d.x},${d.y})`);
  };

  // Call updateBirds function repeatedly to create animation
  setInterval(updateBirds, 50);
};
